'use strict';
// Small helper for TypeScript
function hasKey(obj, key) {
    return key in obj;
}
var getRate = function (base, rates, from, to) {
    // If `from` equals `base`, return the basic exchange rate for the `to` currency
    if (from === base && hasKey(rates, to)) {
        return rates[to];
    }
    // If `to` equals `base`, return the basic inverse rate of the `from` currency
    if (to === base && hasKey(rates, from)) {
        return 1 / rates[from];
    }
    /**
        Otherwise, return the `to` rate multipled by the inverse of the `from` rate to get the
        relative exchange rate between the two currencies
    */
    if (hasKey(rates, from) && hasKey(rates, to)) {
        return rates[to] * (1 / rates[from]);
    }
    throw new Error('`rates` object does not contain either `from` or `to` currency!');
};
var Cashify = /** @class */ (function () {
    function Cashify(_a) {
        var base = _a.base, rates = _a.rates;
        this.options = {
            base: base,
            rates: rates
        };
    }
    /**
    * @param {number} amount Amount of money you want to convert
    * @param {object} options Conversion options
    * @param {string} options.from Currency from which you want to convert
    * @param {string} options.to Currency to which you want to convert
    * @return {number} Conversion result
    */
    Cashify.prototype.convert = function (amount, _a) {
        var from = _a.from, to = _a.to;
        var _b = this.options, base = _b.base, rates = _b.rates;
        // If `from` equals `to`, return the amount of money
        if (from === to) {
            return amount;
        }
        return (amount * 100) * getRate(base, rates, from, to) / 100;
    };
    return Cashify;
}());
/**
* @param {number} amount Amount of money you want to convert
* @param {object} options Conversion options
* @param {string} options.from Currency from which you want to convert
* @param {string} options.to Currency to which you want to convert
* @param {string} options.base Base currency
* @param {string} options.rates Object containing currency rates (for example from an API, such as Open Exchange Rates)
* @return {number} Conversion result
*/
var convert = function (amount, _a) {
    var from = _a.from, to = _a.to, base = _a.base, rates = _a.rates;
    // If `from` equals `to`, return the amount of money
    if (from === to) {
        return amount;
    }
    return (amount * 100) * getRate(base, rates, from, to) / 100;
};
export { Cashify, convert };
